#!/usr/bin/python3
"""
## © University of Southampton IT Innovation Centre, 2018
##
## Copyright in this software belongs to University of Southampton
## IT Innovation Centre of Gamma House, Enterprise Road, 
## Chilworth Science Park, Southampton, SO16 7NS, UK.
##
## This software may not be used, sold, licensed, transferred, copied
## or reproduced in whole or in part in any manner or form or in or
## on any media by any person other than in accordance with the terms
## of the Licence Agreement supplied with the software, or otherwise
## without the prior written consent of the copyright owners.
##
## This software is distributed WITHOUT ANY WARRANTY, without even the
## implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
## PURPOSE, except where stated in the Licence Agreement supplied with
## the software.
##
##      Created By :            Michael Boniface
##      Created Date :          25-02-2018
##      Created for Project :   FLAME
"""

import pytest
import yaml
import requests
import time
import pkg_resources


@pytest.fixture(scope="module")
def streaming_config():
    """
    Reads the service configuration deployed for the streaming simulation test.

    :param request: access the parameters of the fixture
    :return: the python object representing the read YAML file
    """
    rspec = pkg_resources.resource_filename('clmctest.streaming', 'rspec.yml')
    print("rspec file: {0}".format(rspec))

    with open(rspec, 'r') as stream:
        data_loaded = yaml.load(stream)
    return data_loaded


@pytest.fixture(scope="module", autouse=True,
                params=[{'config': {'kapacitor_url': 'http://localhost:8888/chronograf/v1/sources/1/kapacitors', 'kapacitor_file': '/vagrant/test/streaming/kapacitor.json'}}])
def kapacitor_config(request):

    kapacitor_configuration = request.param['config']['kapacitor_file']
    with open(kapacitor_configuration, "r") as rule_file:
        data = "".join(line.strip() for line in rule_file.readlines())

    kapacitor_url = request.param['config']['kapacitor_url']
    requests.post(url=kapacitor_url, data=data, headers={"Content-Type": "application/json"})
    time.sleep(1)
